fn native_import_dependencies(
paths: &ProjectPathsConfig<SolcLanguage>,
sources: &Sources,
) -> NativeDependenciesExpand description
Tracks transitive imports of unmodified tests and scripts after analysis fails.
fn native_import_dependencies(
paths: &ProjectPathsConfig<SolcLanguage>,
sources: &Sources,
) -> NativeDependenciesTracks transitive imports of unmodified tests and scripts after analysis fails.